@@ -118,6 +118,18 @@ has type           => (is => 'ro' , default => sub { 'USMARC' });
 has _importer      => (is => 'ro' , lazy => 1 , builder => '_build_importer' , handles => 'Catmandu::Importer');
 has _importer_args => (is => 'rwp', writer => '_set_importer_args');
 
+# Need to import this method from Catmandu::Importer make it possible
+# to do command line fixing of MARC record. The 'handles' => 'Catmandu::Importer'
+# ignores this fixer magic..
+around generator => sub {
+    my ($orig, $self) = @_;
+    my $generator = $orig->($self);
+    if (my $fixer = $self->_fixer) {
+        return $fixer->fix($generator);
+    }
+    $generator;
+};
+
 sub _build_importer {
     my ($self) = @_;
     my $type = $self->type;
@@ -134,4 +146,5 @@ sub BUILD {
     $self->_set_importer_args($args);
 }
 
+
 1;
